# SFigures-Sen Library

Это учебная библиотека для вычисления площадей геометрических 2D фигур.

## Описание
Библиотека позволяет рассчитать площадь:
* Квадрата
* Круга
* Треугольника

## Установка
Вы можете установить библиотеку прямо из PyPI:
```bash
pip install sfigures_forlab_lab4